@@ -27,10 +27,10 @@ class Activate(Save):
         potential_existing_activities = Activity.query.filter(Activity.entityIdentifier.in_([a.entityIdentifier for a in activities])) \
                                                       .filter(Activity.dateCreated.in_([a.dateCreated for a in activities])) \
                                                       .all()
-        potential_existing_activities_dict = { (a.dateCreated, a.entityIdentifier) : a for a in potential_existing_activities }
+        potential_existing_activities_dict = { (str(a.dateCreated), str(a.entityIdentifier)) : a for a in potential_existing_activities }
         unknown_activities = []
         for activity in activities:
-            existing_activity = potential_existing_activities_dict.get((activity.dateCreated, activity.entityIdentifier))
+            existing_activity = potential_existing_activities_dict.get((str(activity.dateCreated), str(activity.entityIdentifier)))
             if existing_activity:
                 for key, value in vars(existing_activity).items():
                     setattr(activity, key, value)
@@ -79,6 +79,7 @@ class Activate(Save):
             if not entity_id:
                 entity = model(**relationships_in(first_activity.patch, model))
                 entity.activityIdentifier = entity_identifier
+                entity.dateCreated = first_activity.dateCreated
                 Save.add(entity)
                 Activate.get_db().session.flush()
                 insert_activity = entity.__insertActivity__
